"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ChainApi {
    constructor(nodeos_url, contract, fetch) {
        this.nodeos_url = nodeos_url;
        this.contract = contract;
        this.fetch = fetch;
    }
    async getTableRows(payload) {
        return await this.fetch(`${this.nodeos_url}/v1/chain/get_table_rows`, {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify(payload),
        });
    }
    async getDAOByID(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "daos",
            table_key: opts.id,
            lower_bound: opts.id,
            upper_bound: opts.id,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getDAOByOwner(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "daos",
            table_key: opts.owner,
            lower_bound: opts.owner,
            upper_bound: opts.owner,
            key_type: "name",
            index_position: "2",
        });
    }
    async getDAOByDescription(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "daos",
            table_key: opts.descriptionSHA256,
            lower_bound: opts.descriptionSHA256,
            upper_bound: opts.descriptionSHA256,
            key_type: "sha256",
            index_position: "3",
        });
    }
    async getProposalByID(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "proposals",
            table_key: opts.id,
            lower_bound: opts.id,
            upper_bound: opts.id,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getProposalByProposer(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "proposals",
            table_key: opts.proposer,
            lower_bound: opts.proposer,
            upper_bound: opts.proposer,
            key_type: "name",
            index_position: "2",
        });
    }
    async getNFTProposalByID(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "nftproposals",
            table_key: opts.id,
            lower_bound: opts.id,
            upper_bound: opts.id,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getNFTProposalByProposer(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "nftproposals",
            table_key: opts.proposer,
            lower_bound: opts.proposer,
            upper_bound: opts.proposer,
            key_type: "name",
            index_position: "2",
        });
    }
    async getRetireProposal(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "rtrproposals",
            table_key: opts.id,
            lower_bound: opts.id,
            upper_bound: opts.id,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getRetireProposalByProposer(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.daoID,
            table: "rtrproposals",
            table_key: opts.proposer,
            lower_bound: opts.proposer,
            upper_bound: opts.proposer,
            key_type: "name",
            index_position: "2",
        });
    }
}
exports.default = ChainApi;
